@@ -1,6 +1,6 @@
 # -*-shell-*-
 
-# $Id: functions.sh,v 1.4 1998/09/16 23:52:44 phil Exp $
+# $Id: functions.sh,v 1.6 2000/04/13 08:34:28 phil Exp $
 # Copyright (c) 1998 Philip Hands <phil@hands.com>
 # Distributed under the terms of the GPL.
 
@@ -21,7 +21,7 @@ description=$1; shift
 
 echo "debian-test TESTING: $description"
 
-  if eval $*
+  if ( eval $@ )
   then
     result="PASSED"
   else
@@ -35,4 +35,4 @@ echo "debian-test RESULT: $description: $result"
 # put out a message that will get to the user in -s (summary) mode
 printmsg() {
   echo "debian-test MESSAGE: $*"
-}
\ No newline at end of file
+}
